@@ -13,10 +13,13 @@
 (custom-add-loads 'TeX-command '("tex"))
 (custom-add-loads 'TeX-command-name '("tex"))
 (custom-add-loads 'TeX-commands '("tex-buf"))
-(custom-add-loads 'TeX-indentation '("latex"))
-(custom-add-loads 'TeX-macro '("latex"))
+(custom-add-loads 'TeX '("tex"))
+(custom-add-loads 'TeX-indentation '("latex" "tex"))
+(custom-add-loads 'TeX-macro '("latex" "tex"))
+(custom-add-loads 'TeX-quote '("tex"))
 (custom-add-loads 'LaTeX-indentation '("latex"))
 (custom-add-loads 'LaTeX '("latex" "tex"))
+(custom-add-loads 'TeX-file-extension '("tex"))
 (custom-add-loads 'TeX-file '("tex"))
 
 ;;; custom-load.el ends here
